@@ -1,9 +1,12 @@
 import sys
+import uuid
+import warnings
 
 from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 from ploomber.executors import Parallel
 from ploomber.telemetry import telemetry
+from ploomber.cli.cloud import _write_pipeline
 
 
 # this parameter is only set to True when calling "ploomber interactive"
@@ -50,26 +53,47 @@ def main(payload, render_only=False):
                      f'To build a single task, try: {suggestion!r}')
 
     dag, args = parser.load_from_entry_point_arg()
-
+    pid = str(uuid.uuid4())
+    res = str(
+        _write_pipeline(pipeline_id=pid,
+                        status='started',
+                        pipeline_name=dag.name))
+    if 'Error' in res:
+        warnings.warn(res)
     # when using the parallel executor from the CLI, ensure we print progress
     # to stdout
     if isinstance(dag.executor, Parallel):
         dag.executor.print_progress = True
-
-    if render_only:
-        dag.render()
-    else:
-        if args.partially:
-            report = dag.build_partially(args.partially,
-                                         force=args.force,
-                                         debug=args.debug,
-                                         skip_upstream=args.skip_upstream)
+    try:
+        if render_only:
+            dag.render()
         else:
-            report = dag.build(force=args.force, debug=args.debug)
+            if args.partially:
+                report = dag.build_partially(args.partially,
+                                             force=args.force,
+                                             debug=args.debug,
+                                             skip_upstream=args.skip_upstream)
+            else:
+                report = dag.build(force=args.force, debug=args.debug)
+    except Exception as e:
+        res = str(
+            _write_pipeline(pipeline_id=pid,
+                            status='error',
+                            pipeline_name=dag.name,
+                            log=str(e.args)))
+        if 'Error' in res:
+            warnings.warn(res)
+        raise
 
-        if report:
-            print(report)
+    if report:
+        print(report)
 
     payload['dag'] = dag
-
+    res = str(
+        _write_pipeline(pipeline_id=pid,
+                        status='finished',
+                        pipeline_name=dag.name,
+                        dag=telemetry.parse_dag(dag)))
+    if 'Error' in res:
+        warnings.warn(res)
     return dag
