@@ -1,5 +1,5 @@
 from ploomber.exceptions import MissingClientError
-from ploomber.util.dotted_path import DottedPathSpec
+from ploomber.util.dotted_path import DottedPath
 
 
 class ClientMixin:
@@ -25,7 +25,7 @@ class ClientMixin:
 
             return dag_client
 
-        if isinstance(self._client, DottedPathSpec):
+        if isinstance(self._client, DottedPath):
             # NOTE: should we test the output ot self._client()?
             # maybe check if it's a subclass of the Client abstract class
             self._client = self._client()
